@@ -2,7 +2,11 @@ from typing import Type
 
 from PyQt6.QtWidgets import QApplication
 
-from function2widgets.common import AlreadyRegisteredError, NotRegisteredError
+from function2widgets.common import (
+    AlreadyRegisteredError,
+    NotRegisteredError,
+    safe_read_file,
+)
 from function2widgets.description import ParameterDescription
 from function2widgets.widget import BaseParameterWidget
 from function2widgets.widgets.allwidgets import BASIC_PARAMETER_WIDGETS
@@ -38,9 +42,9 @@ class ParameterWidgetFactory(object):
 
     def get_widget_class(self, widget_type: str) -> Type[BaseParameterWidget]:
         if not self.is_registered(widget_type):
-            raise NotRegisteredError(QApplication.tr(
-                f"widget type {widget_type} not registered"
-            ))
+            raise NotRegisteredError(
+                QApplication.tr(f"widget type {widget_type} not registered")
+            )
         return self._widget_classes[widget_type]
 
     def clear(self):
@@ -50,7 +54,9 @@ class ParameterWidgetFactory(object):
         widget_class = self.get_widget_class(widget_type)
         return widget_class(**kwargs)
 
-    def create_widget_from_description(self, param_description: ParameterDescription) -> BaseParameterWidget:
+    def create_widget_from_description(
+        self, param_description: ParameterDescription
+    ) -> BaseParameterWidget:
         widget_description = param_description.widget
 
         if not widget_description:
@@ -70,10 +76,19 @@ class ParameterWidgetFactory(object):
 
         widget_type = widget_type or param_description.type
 
+        # 针对stylesheet参数做一些特殊处理
+        # 需要判断stylesheet是样式表本身还是一个执行样式表文件的路径
+        # 如果是一个指向文件的路径，则需要读取文件内容并设置为样式表
+        if "stylesheet" in widget_init_args:
+            stylesheet = widget_init_args["stylesheet"]
+            stylesheet = safe_read_file(stylesheet)
+            if stylesheet is not None:
+                widget_init_args["stylesheet"] = stylesheet
+
         args = {
             "default": param_description.default,
             "parent": None,
-            **widget_init_args
+            **widget_init_args,
         }
         widget = self.create_widget(widget_type, **args)
         widget.parameter_name = param_description.name
